#!/usr/bin/env python
# coding: utf-8

import shutil, os, sys
import numpy as np

# Script for merging MESA profiles from various LOGS output directories in one destination directory
# Arguments are 1) Name of destination directory 2) the paths to LOGS directories to merge
num_dirs = len(sys.argv) - 1

dest_dir = sys.argv[1]
if dest_dir[-1]!= "/":
    dest_dir += "/"
os.mkdir(dest_dir)
num_profiles = 0
new_prof_ary = []
final_prof_index_ary = []
new_prof_ind = 1
for ind, dirname in enumerate(sys.argv[2:]):
    if dirname[-1] != "/":
        dirname += "/"
    print("\nEntering", dirname)
    # Enter LOGS directory and read profiles.index file
    index_ary = np.genfromtxt(dirname + "profiles.index", skip_header=1)
    if len(index_ary.shape) > 1:
        prof_ary = index_ary[:, 2]
    else:
        prof_ary = [index_ary[2]]
    # Copy each profile to new destination directory and rename
    for prof_ind in prof_ary:
        shutil.copy(dirname + "profile" + str(int(prof_ind)) + ".data",
                    dest_dir + "profile" + str(new_prof_ind) + ".data")
        print(new_prof_ind, "Copying", "profile" + str(int(prof_ind)) + ".data")
        new_prof_ary.append(new_prof_ind)
        new_prof_ind += 1

    # Create array containing all necessary information for a new profiles.index entry
    if len(index_ary.shape) > 1:
        total_data = np.column_stack([index_ary[:, :2], new_prof_ary])
    else:
        total_data = np.column_stack([[index_ary[0]],[index_ary[1]], new_prof_ary])
    # Check if data needs to be added to existing profiles.index
    if os.path.isfile(dest_dir + "profiles.index"):
        stored_data = np.genfromtxt(dest_dir + "profiles.index", skip_header=1)
        final_prof_index_ary = np.vstack([stored_data, total_data])
    else:
        final_prof_index_ary = total_data
    header = "\t" + str(new_prof_ind  - 1) + " models.    lines hold model number, priority, and profile number."
    np.savetxt(dest_dir + "profiles.index", final_prof_index_ary, fmt="%d", delimiter="\t",
               header=header, comments="")
    # Reset profile numbers array
    new_prof_ary = []

#TODO: add warning when model numbers are not increasing monotonically?




